r"""Contain sequence generators."""

from __future__ import annotations

__all__ = [
    "Abs",
    "AbsSequenceGenerator",
    "Acosh",
    "AcoshSequenceGenerator",
    "Add",
    "AddScalar",
    "AddScalarSequenceGenerator",
    "AddSequenceGenerator",
    "Arange",
    "ArangeSequenceGenerator",
    "Asinh",
    "AsinhSequenceGenerator",
    "AsinhUniform",
    "AsinhUniformSequenceGenerator",
    "Atanh",
    "AtanhSequenceGenerator",
    "AutoRegressive",
    "AutoRegressiveSequenceGenerator",
    "BaseSequenceGenerator",
    "BaseWrapperSequenceGenerator",
    "Cat2",
    "Cat2SequenceGenerator",
    "Cauchy",
    "CauchySequenceGenerator",
    "Clamp",
    "ClampSequenceGenerator",
    "Constant",
    "ConstantSequenceGenerator",
    "Cosh",
    "CoshSequenceGenerator",
    "Cumsum",
    "CumsumSequenceGenerator",
    "Div",
    "DivSequenceGenerator",
    "Exp",
    "ExpSequenceGenerator",
    "Exponential",
    "ExponentialSequenceGenerator",
    "Float",
    "FloatSequenceGenerator",
    "Fmod",
    "FmodSequenceGenerator",
    "Full",
    "FullSequenceGenerator",
    "HalfCauchy",
    "HalfCauchySequenceGenerator",
    "HalfNormal",
    "HalfNormalSequenceGenerator",
    "Linear",
    "LinearSequenceGenerator",
    "Log",
    "LogNormal",
    "LogNormalSequenceGenerator",
    "LogSequenceGenerator",
    "LogUniform",
    "LogUniformSequenceGenerator",
    "Long",
    "LongSequenceGenerator",
    "Mul",
    "MulScalar",
    "MulScalarSequenceGenerator",
    "MulSequenceGenerator",
    "Multinomial",
    "MultinomialChoice",
    "MultinomialChoiceSequenceGenerator",
    "MultinomialSequenceGenerator",
    "Neg",
    "NegSequenceGenerator",
    "Normal",
    "NormalSequenceGenerator",
    "Periodic",
    "PeriodicSequenceGenerator",
    "Poisson",
    "PoissonSequenceGenerator",
    "RandAsinhUniform",
    "RandAsinhUniformSequenceGenerator",
    "RandCauchy",
    "RandCauchySequenceGenerator",
    "RandExponential",
    "RandExponentialSequenceGenerator",
    "RandHalfCauchy",
    "RandHalfCauchySequenceGenerator",
    "RandHalfNormal",
    "RandHalfNormalSequenceGenerator",
    "RandInt",
    "RandIntSequenceGenerator",
    "RandLogNormal",
    "RandLogNormalSequenceGenerator",
    "RandLogUniform",
    "RandLogUniformSequenceGenerator",
    "RandNormal",
    "RandNormalSequenceGenerator",
    "RandPoisson",
    "RandPoissonSequenceGenerator",
    "RandTruncCauchy",
    "RandTruncCauchySequenceGenerator",
    "RandTruncExponential",
    "RandTruncExponentialSequenceGenerator",
    "RandTruncHalfCauchy",
    "RandTruncHalfCauchySequenceGenerator",
    "RandTruncHalfNormal",
    "RandTruncHalfNormalSequenceGenerator",
    "RandTruncLogNormal",
    "RandTruncLogNormalSequenceGenerator",
    "RandTruncNormal",
    "RandTruncNormalSequenceGenerator",
    "RandUniform",
    "RandUniformSequenceGenerator",
    "RandWienerProcess",
    "RandWienerProcessSequenceGenerator",
    "SineWave",
    "SineWaveSequenceGenerator",
    "Sinh",
    "SinhSequenceGenerator",
    "Sort",
    "SortSequenceGenerator",
    "Sqrt",
    "SqrtSequenceGenerator",
    "Sub",
    "SubSequenceGenerator",
    "Tanh",
    "TanhSequenceGenerator",
    "TensorSequence",
    "Time",
    "TimeSequenceGenerator",
    "TruncCauchy",
    "TruncCauchySequenceGenerator",
    "TruncExponential",
    "TruncExponentialSequenceGenerator",
    "TruncHalfCauchy",
    "TruncHalfCauchySequenceGenerator",
    "TruncHalfNormal",
    "TruncHalfNormalSequenceGenerator",
    "TruncLogNormal",
    "TruncLogNormalSequenceGenerator",
    "TruncNormal",
    "TruncNormalSequenceGenerator",
    "Uniform",
    "UniformCategorical",
    "UniformCategoricalSequenceGenerator",
    "UniformSequenceGenerator",
    "is_sequence_generator_config",
    "setup_sequence_generator",
]

from startorch.sequence.ar import AutoRegressiveSequenceGenerator
from startorch.sequence.ar import AutoRegressiveSequenceGenerator as AutoRegressive
from startorch.sequence.base import (
    BaseSequenceGenerator,
    is_sequence_generator_config,
    setup_sequence_generator,
)
from startorch.sequence.categorical import MultinomialSequenceGenerator
from startorch.sequence.categorical import MultinomialSequenceGenerator as Multinomial
from startorch.sequence.categorical import UniformCategoricalSequenceGenerator
from startorch.sequence.categorical import (
    UniformCategoricalSequenceGenerator as UniformCategorical,
)
from startorch.sequence.cauchy import CauchySequenceGenerator
from startorch.sequence.cauchy import CauchySequenceGenerator as Cauchy
from startorch.sequence.cauchy import RandCauchySequenceGenerator
from startorch.sequence.cauchy import RandCauchySequenceGenerator as RandCauchy
from startorch.sequence.cauchy import RandTruncCauchySequenceGenerator
from startorch.sequence.cauchy import (
    RandTruncCauchySequenceGenerator as RandTruncCauchy,
)
from startorch.sequence.cauchy import TruncCauchySequenceGenerator
from startorch.sequence.cauchy import TruncCauchySequenceGenerator as TruncCauchy
from startorch.sequence.choice import MultinomialChoiceSequenceGenerator
from startorch.sequence.choice import (
    MultinomialChoiceSequenceGenerator as MultinomialChoice,
)
from startorch.sequence.constant import ConstantSequenceGenerator
from startorch.sequence.constant import ConstantSequenceGenerator as Constant
from startorch.sequence.constant import FullSequenceGenerator
from startorch.sequence.constant import FullSequenceGenerator as Full
from startorch.sequence.dtype import FloatSequenceGenerator
from startorch.sequence.dtype import FloatSequenceGenerator as Float
from startorch.sequence.dtype import LongSequenceGenerator
from startorch.sequence.dtype import LongSequenceGenerator as Long
from startorch.sequence.exponential import ExponentialSequenceGenerator
from startorch.sequence.exponential import ExponentialSequenceGenerator as Exponential
from startorch.sequence.exponential import RandExponentialSequenceGenerator
from startorch.sequence.exponential import (
    RandExponentialSequenceGenerator as RandExponential,
)
from startorch.sequence.exponential import RandTruncExponentialSequenceGenerator
from startorch.sequence.exponential import (
    RandTruncExponentialSequenceGenerator as RandTruncExponential,
)
from startorch.sequence.exponential import TruncExponentialSequenceGenerator
from startorch.sequence.exponential import (
    TruncExponentialSequenceGenerator as TruncExponential,
)
from startorch.sequence.halfcauchy import HalfCauchySequenceGenerator
from startorch.sequence.halfcauchy import HalfCauchySequenceGenerator as HalfCauchy
from startorch.sequence.halfcauchy import RandHalfCauchySequenceGenerator
from startorch.sequence.halfcauchy import (
    RandHalfCauchySequenceGenerator as RandHalfCauchy,
)
from startorch.sequence.halfcauchy import RandTruncHalfCauchySequenceGenerator
from startorch.sequence.halfcauchy import (
    RandTruncHalfCauchySequenceGenerator as RandTruncHalfCauchy,
)
from startorch.sequence.halfcauchy import TruncHalfCauchySequenceGenerator
from startorch.sequence.halfcauchy import (
    TruncHalfCauchySequenceGenerator as TruncHalfCauchy,
)
from startorch.sequence.halfnormal import HalfNormalSequenceGenerator
from startorch.sequence.halfnormal import HalfNormalSequenceGenerator as HalfNormal
from startorch.sequence.halfnormal import RandHalfNormalSequenceGenerator
from startorch.sequence.halfnormal import (
    RandHalfNormalSequenceGenerator as RandHalfNormal,
)
from startorch.sequence.halfnormal import RandTruncHalfNormalSequenceGenerator
from startorch.sequence.halfnormal import (
    RandTruncHalfNormalSequenceGenerator as RandTruncHalfNormal,
)
from startorch.sequence.halfnormal import TruncHalfNormalSequenceGenerator
from startorch.sequence.halfnormal import (
    TruncHalfNormalSequenceGenerator as TruncHalfNormal,
)
from startorch.sequence.joining import Cat2SequenceGenerator
from startorch.sequence.joining import Cat2SequenceGenerator as Cat2
from startorch.sequence.linear import LinearSequenceGenerator
from startorch.sequence.linear import LinearSequenceGenerator as Linear
from startorch.sequence.lognormal import LogNormalSequenceGenerator
from startorch.sequence.lognormal import LogNormalSequenceGenerator as LogNormal
from startorch.sequence.lognormal import RandLogNormalSequenceGenerator
from startorch.sequence.lognormal import RandLogNormalSequenceGenerator as RandLogNormal
from startorch.sequence.lognormal import RandTruncLogNormalSequenceGenerator
from startorch.sequence.lognormal import (
    RandTruncLogNormalSequenceGenerator as RandTruncLogNormal,
)
from startorch.sequence.lognormal import TruncLogNormalSequenceGenerator
from startorch.sequence.lognormal import (
    TruncLogNormalSequenceGenerator as TruncLogNormal,
)
from startorch.sequence.math import AbsSequenceGenerator
from startorch.sequence.math import AbsSequenceGenerator as Abs
from startorch.sequence.math import AddScalarSequenceGenerator
from startorch.sequence.math import AddScalarSequenceGenerator as AddScalar
from startorch.sequence.math import AddSequenceGenerator
from startorch.sequence.math import AddSequenceGenerator as Add
from startorch.sequence.math import ClampSequenceGenerator
from startorch.sequence.math import ClampSequenceGenerator as Clamp
from startorch.sequence.math import CumsumSequenceGenerator
from startorch.sequence.math import CumsumSequenceGenerator as Cumsum
from startorch.sequence.math import DivSequenceGenerator
from startorch.sequence.math import DivSequenceGenerator as Div
from startorch.sequence.math import ExpSequenceGenerator
from startorch.sequence.math import ExpSequenceGenerator as Exp
from startorch.sequence.math import FmodSequenceGenerator
from startorch.sequence.math import FmodSequenceGenerator as Fmod
from startorch.sequence.math import LogSequenceGenerator
from startorch.sequence.math import LogSequenceGenerator as Log
from startorch.sequence.math import MulScalarSequenceGenerator
from startorch.sequence.math import MulScalarSequenceGenerator as MulScalar
from startorch.sequence.math import MulSequenceGenerator
from startorch.sequence.math import MulSequenceGenerator as Mul
from startorch.sequence.math import NegSequenceGenerator
from startorch.sequence.math import NegSequenceGenerator as Neg
from startorch.sequence.math import SqrtSequenceGenerator
from startorch.sequence.math import SqrtSequenceGenerator as Sqrt
from startorch.sequence.math import SubSequenceGenerator
from startorch.sequence.math import SubSequenceGenerator as Sub
from startorch.sequence.normal import NormalSequenceGenerator
from startorch.sequence.normal import NormalSequenceGenerator as Normal
from startorch.sequence.normal import RandNormalSequenceGenerator
from startorch.sequence.normal import RandNormalSequenceGenerator as RandNormal
from startorch.sequence.normal import RandTruncNormalSequenceGenerator
from startorch.sequence.normal import (
    RandTruncNormalSequenceGenerator as RandTruncNormal,
)
from startorch.sequence.normal import TruncNormalSequenceGenerator
from startorch.sequence.normal import TruncNormalSequenceGenerator as TruncNormal
from startorch.sequence.periodic import PeriodicSequenceGenerator
from startorch.sequence.periodic import PeriodicSequenceGenerator as Periodic
from startorch.sequence.poisson import PoissonSequenceGenerator
from startorch.sequence.poisson import PoissonSequenceGenerator as Poisson
from startorch.sequence.poisson import RandPoissonSequenceGenerator
from startorch.sequence.poisson import RandPoissonSequenceGenerator as RandPoisson
from startorch.sequence.range import ArangeSequenceGenerator
from startorch.sequence.range import ArangeSequenceGenerator as Arange
from startorch.sequence.sort import SortSequenceGenerator
from startorch.sequence.sort import SortSequenceGenerator as Sort
from startorch.sequence.tensor import TensorSequenceGenerator as TensorSequence
from startorch.sequence.time import TimeSequenceGenerator
from startorch.sequence.time import TimeSequenceGenerator as Time
from startorch.sequence.trigo import AcoshSequenceGenerator
from startorch.sequence.trigo import AcoshSequenceGenerator as Acosh
from startorch.sequence.trigo import AsinhSequenceGenerator
from startorch.sequence.trigo import AsinhSequenceGenerator as Asinh
from startorch.sequence.trigo import AtanhSequenceGenerator
from startorch.sequence.trigo import AtanhSequenceGenerator as Atanh
from startorch.sequence.trigo import CoshSequenceGenerator
from startorch.sequence.trigo import CoshSequenceGenerator as Cosh
from startorch.sequence.trigo import SinhSequenceGenerator
from startorch.sequence.trigo import SinhSequenceGenerator as Sinh
from startorch.sequence.trigo import TanhSequenceGenerator
from startorch.sequence.trigo import TanhSequenceGenerator as Tanh
from startorch.sequence.uniform import AsinhUniformSequenceGenerator
from startorch.sequence.uniform import AsinhUniformSequenceGenerator as AsinhUniform
from startorch.sequence.uniform import LogUniformSequenceGenerator
from startorch.sequence.uniform import LogUniformSequenceGenerator as LogUniform
from startorch.sequence.uniform import RandAsinhUniformSequenceGenerator
from startorch.sequence.uniform import (
    RandAsinhUniformSequenceGenerator as RandAsinhUniform,
)
from startorch.sequence.uniform import RandIntSequenceGenerator
from startorch.sequence.uniform import RandIntSequenceGenerator as RandInt
from startorch.sequence.uniform import RandLogUniformSequenceGenerator
from startorch.sequence.uniform import RandLogUniformSequenceGenerator as RandLogUniform
from startorch.sequence.uniform import RandUniformSequenceGenerator
from startorch.sequence.uniform import RandUniformSequenceGenerator as RandUniform
from startorch.sequence.uniform import UniformSequenceGenerator
from startorch.sequence.uniform import UniformSequenceGenerator as Uniform
from startorch.sequence.wave import SineWaveSequenceGenerator
from startorch.sequence.wave import SineWaveSequenceGenerator as SineWave
from startorch.sequence.wiener import RandWienerProcessSequenceGenerator
from startorch.sequence.wiener import (
    RandWienerProcessSequenceGenerator as RandWienerProcess,
)
from startorch.sequence.wrapper import BaseWrapperSequenceGenerator
