r"""Contain tensor generators."""

from __future__ import annotations

__all__ = [
    "Abs",
    "AbsTensorGenerator",
    "Acosh",
    "AcoshTensorGenerator",
    "Add",
    "AddScalar",
    "AddScalarTensorGenerator",
    "AddTensorGenerator",
    "Asinh",
    "AsinhTensorGenerator",
    "AsinhUniform",
    "AsinhUniformTensorGenerator",
    "Atanh",
    "AtanhTensorGenerator",
    "BaseTensorGenerator",
    "BaseWrapperTensorGenerator",
    "Cauchy",
    "CauchyTensorGenerator",
    "Clamp",
    "ClampTensorGenerator",
    "Cosh",
    "CoshTensorGenerator",
    "Div",
    "DivTensorGenerator",
    "Exp",
    "ExpTensorGenerator",
    "Exponential",
    "ExponentialTensorGenerator",
    "Float",
    "FloatTensorGenerator",
    "Fmod",
    "FmodTensorGenerator",
    "Full",
    "FullTensorGenerator",
    "HalfCauchy",
    "HalfCauchyTensorGenerator",
    "HalfNormal",
    "HalfNormalTensorGenerator",
    "Log",
    "LogNormal",
    "LogNormalTensorGenerator",
    "LogTensorGenerator",
    "LogUniform",
    "LogUniformTensorGenerator",
    "Long",
    "LongTensorGenerator",
    "Mul",
    "MulScalar",
    "MulScalarTensorGenerator",
    "MulTensorGenerator",
    "Multinomial",
    "MultinomialChoice",
    "MultinomialChoiceTensorGenerator",
    "MultinomialTensorGenerator",
    "Neg",
    "NegTensorGenerator",
    "Normal",
    "NormalTensorGenerator",
    "Poisson",
    "PoissonTensorGenerator",
    "RandAsinhUniform",
    "RandAsinhUniformTensorGenerator",
    "RandCauchy",
    "RandCauchyTensorGenerator",
    "RandExponential",
    "RandExponentialTensorGenerator",
    "RandHalfCauchy",
    "RandHalfCauchyTensorGenerator",
    "RandHalfNormal",
    "RandHalfNormalTensorGenerator",
    "RandInt",
    "RandIntTensorGenerator",
    "RandLogNormal",
    "RandLogNormalTensorGenerator",
    "RandLogUniform",
    "RandLogUniformTensorGenerator",
    "RandNormal",
    "RandNormalTensorGenerator",
    "RandPoisson",
    "RandPoissonTensorGenerator",
    "RandTruncCauchy",
    "RandTruncCauchyTensorGenerator",
    "RandTruncExponential",
    "RandTruncExponentialTensorGenerator",
    "RandTruncHalfCauchy",
    "RandTruncHalfCauchyTensorGenerator",
    "RandTruncHalfNormal",
    "RandTruncHalfNormalTensorGenerator",
    "RandTruncLogNormal",
    "RandTruncLogNormalTensorGenerator",
    "RandTruncNormal",
    "RandTruncNormalTensorGenerator",
    "RandUniform",
    "RandUniformTensorGenerator",
    "Sinh",
    "SinhTensorGenerator",
    "Sqrt",
    "SqrtTensorGenerator",
    "Sub",
    "SubTensorGenerator",
    "Tanh",
    "TanhTensorGenerator",
    "TruncCauchy",
    "TruncCauchyTensorGenerator",
    "TruncExponential",
    "TruncExponentialTensorGenerator",
    "TruncHalfCauchy",
    "TruncHalfCauchyTensorGenerator",
    "TruncHalfNormal",
    "TruncHalfNormalTensorGenerator",
    "TruncLogNormal",
    "TruncLogNormalTensorGenerator",
    "TruncNormal",
    "TruncNormalTensorGenerator",
    "Uniform",
    "UniformCategorical",
    "UniformCategoricalTensorGenerator",
    "UniformTensorGenerator",
    "is_tensor_generator_config",
    "setup_tensor_generator",
]

from startorch.tensor.base import (
    BaseTensorGenerator,
    is_tensor_generator_config,
    setup_tensor_generator,
)
from startorch.tensor.categorical import MultinomialTensorGenerator
from startorch.tensor.categorical import MultinomialTensorGenerator as Multinomial
from startorch.tensor.categorical import UniformCategoricalTensorGenerator
from startorch.tensor.categorical import (
    UniformCategoricalTensorGenerator as UniformCategorical,
)
from startorch.tensor.cauchy import CauchyTensorGenerator
from startorch.tensor.cauchy import CauchyTensorGenerator as Cauchy
from startorch.tensor.cauchy import RandCauchyTensorGenerator
from startorch.tensor.cauchy import RandCauchyTensorGenerator as RandCauchy
from startorch.tensor.cauchy import RandTruncCauchyTensorGenerator
from startorch.tensor.cauchy import RandTruncCauchyTensorGenerator as RandTruncCauchy
from startorch.tensor.cauchy import TruncCauchyTensorGenerator
from startorch.tensor.cauchy import TruncCauchyTensorGenerator as TruncCauchy
from startorch.tensor.choice import MultinomialChoiceTensorGenerator
from startorch.tensor.choice import (
    MultinomialChoiceTensorGenerator as MultinomialChoice,
)
from startorch.tensor.constant import FullTensorGenerator
from startorch.tensor.constant import FullTensorGenerator as Full
from startorch.tensor.dtype import FloatTensorGenerator
from startorch.tensor.dtype import FloatTensorGenerator as Float
from startorch.tensor.dtype import LongTensorGenerator
from startorch.tensor.dtype import LongTensorGenerator as Long
from startorch.tensor.exponential import ExponentialTensorGenerator
from startorch.tensor.exponential import ExponentialTensorGenerator as Exponential
from startorch.tensor.exponential import RandExponentialTensorGenerator
from startorch.tensor.exponential import (
    RandExponentialTensorGenerator as RandExponential,
)
from startorch.tensor.exponential import RandTruncExponentialTensorGenerator
from startorch.tensor.exponential import (
    RandTruncExponentialTensorGenerator as RandTruncExponential,
)
from startorch.tensor.exponential import TruncExponentialTensorGenerator
from startorch.tensor.exponential import (
    TruncExponentialTensorGenerator as TruncExponential,
)
from startorch.tensor.halfcauchy import HalfCauchyTensorGenerator
from startorch.tensor.halfcauchy import HalfCauchyTensorGenerator as HalfCauchy
from startorch.tensor.halfcauchy import RandHalfCauchyTensorGenerator
from startorch.tensor.halfcauchy import RandHalfCauchyTensorGenerator as RandHalfCauchy
from startorch.tensor.halfcauchy import RandTruncHalfCauchyTensorGenerator
from startorch.tensor.halfcauchy import (
    RandTruncHalfCauchyTensorGenerator as RandTruncHalfCauchy,
)
from startorch.tensor.halfcauchy import TruncHalfCauchyTensorGenerator
from startorch.tensor.halfcauchy import (
    TruncHalfCauchyTensorGenerator as TruncHalfCauchy,
)
from startorch.tensor.halfnormal import HalfNormalTensorGenerator
from startorch.tensor.halfnormal import HalfNormalTensorGenerator as HalfNormal
from startorch.tensor.halfnormal import RandHalfNormalTensorGenerator
from startorch.tensor.halfnormal import RandHalfNormalTensorGenerator as RandHalfNormal
from startorch.tensor.halfnormal import RandTruncHalfNormalTensorGenerator
from startorch.tensor.halfnormal import (
    RandTruncHalfNormalTensorGenerator as RandTruncHalfNormal,
)
from startorch.tensor.halfnormal import TruncHalfNormalTensorGenerator
from startorch.tensor.halfnormal import (
    TruncHalfNormalTensorGenerator as TruncHalfNormal,
)
from startorch.tensor.lognormal import LogNormalTensorGenerator
from startorch.tensor.lognormal import LogNormalTensorGenerator as LogNormal
from startorch.tensor.lognormal import RandLogNormalTensorGenerator
from startorch.tensor.lognormal import RandLogNormalTensorGenerator as RandLogNormal
from startorch.tensor.lognormal import RandTruncLogNormalTensorGenerator
from startorch.tensor.lognormal import (
    RandTruncLogNormalTensorGenerator as RandTruncLogNormal,
)
from startorch.tensor.lognormal import TruncLogNormalTensorGenerator
from startorch.tensor.lognormal import TruncLogNormalTensorGenerator as TruncLogNormal
from startorch.tensor.math import AbsTensorGenerator
from startorch.tensor.math import AbsTensorGenerator as Abs
from startorch.tensor.math import AddScalarTensorGenerator
from startorch.tensor.math import AddScalarTensorGenerator as AddScalar
from startorch.tensor.math import AddTensorGenerator
from startorch.tensor.math import AddTensorGenerator as Add
from startorch.tensor.math import ClampTensorGenerator
from startorch.tensor.math import ClampTensorGenerator as Clamp
from startorch.tensor.math import DivTensorGenerator
from startorch.tensor.math import DivTensorGenerator as Div
from startorch.tensor.math import ExpTensorGenerator
from startorch.tensor.math import ExpTensorGenerator as Exp
from startorch.tensor.math import FmodTensorGenerator
from startorch.tensor.math import FmodTensorGenerator as Fmod
from startorch.tensor.math import LogTensorGenerator
from startorch.tensor.math import LogTensorGenerator as Log
from startorch.tensor.math import MulScalarTensorGenerator
from startorch.tensor.math import MulScalarTensorGenerator as MulScalar
from startorch.tensor.math import MulTensorGenerator
from startorch.tensor.math import MulTensorGenerator as Mul
from startorch.tensor.math import NegTensorGenerator
from startorch.tensor.math import NegTensorGenerator as Neg
from startorch.tensor.math import SqrtTensorGenerator
from startorch.tensor.math import SqrtTensorGenerator as Sqrt
from startorch.tensor.math import SubTensorGenerator
from startorch.tensor.math import SubTensorGenerator as Sub
from startorch.tensor.normal import NormalTensorGenerator
from startorch.tensor.normal import NormalTensorGenerator as Normal
from startorch.tensor.normal import RandNormalTensorGenerator
from startorch.tensor.normal import RandNormalTensorGenerator as RandNormal
from startorch.tensor.normal import RandTruncNormalTensorGenerator
from startorch.tensor.normal import RandTruncNormalTensorGenerator as RandTruncNormal
from startorch.tensor.normal import TruncNormalTensorGenerator
from startorch.tensor.normal import TruncNormalTensorGenerator as TruncNormal
from startorch.tensor.poisson import PoissonTensorGenerator
from startorch.tensor.poisson import PoissonTensorGenerator as Poisson
from startorch.tensor.poisson import RandPoissonTensorGenerator
from startorch.tensor.poisson import RandPoissonTensorGenerator as RandPoisson
from startorch.tensor.trigo import AcoshTensorGenerator
from startorch.tensor.trigo import AcoshTensorGenerator as Acosh
from startorch.tensor.trigo import AsinhTensorGenerator
from startorch.tensor.trigo import AsinhTensorGenerator as Asinh
from startorch.tensor.trigo import AtanhTensorGenerator
from startorch.tensor.trigo import AtanhTensorGenerator as Atanh
from startorch.tensor.trigo import CoshTensorGenerator
from startorch.tensor.trigo import CoshTensorGenerator as Cosh
from startorch.tensor.trigo import SinhTensorGenerator
from startorch.tensor.trigo import SinhTensorGenerator as Sinh
from startorch.tensor.trigo import TanhTensorGenerator
from startorch.tensor.trigo import TanhTensorGenerator as Tanh
from startorch.tensor.uniform import AsinhUniformTensorGenerator
from startorch.tensor.uniform import AsinhUniformTensorGenerator as AsinhUniform
from startorch.tensor.uniform import LogUniformTensorGenerator
from startorch.tensor.uniform import LogUniformTensorGenerator as LogUniform
from startorch.tensor.uniform import RandAsinhUniformTensorGenerator
from startorch.tensor.uniform import RandAsinhUniformTensorGenerator as RandAsinhUniform
from startorch.tensor.uniform import RandIntTensorGenerator
from startorch.tensor.uniform import RandIntTensorGenerator as RandInt
from startorch.tensor.uniform import RandLogUniformTensorGenerator
from startorch.tensor.uniform import RandLogUniformTensorGenerator as RandLogUniform
from startorch.tensor.uniform import RandUniformTensorGenerator
from startorch.tensor.uniform import RandUniformTensorGenerator as RandUniform
from startorch.tensor.uniform import UniformTensorGenerator
from startorch.tensor.uniform import UniformTensorGenerator as Uniform
from startorch.tensor.wrapper import BaseWrapperTensorGenerator
